# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'BlueprintWithCursorBlueprintPropertiesStatus',
    'GetBlueprintPropertiesResourcesItemPropertiesType',
    'GetBlueprintPropertiesStatus',
    'SyncWithCursorSyncPropertiesState',
]


class BlueprintWithCursorBlueprintPropertiesStatus(str, Enum):
    CREATED = "created"
    PAUSED = "paused"
    IN_SYNC = "in_sync"
    SYNCING = "syncing"
    ERROR = "error"


class GetBlueprintPropertiesResourcesItemPropertiesType(str, Enum):
    """
    type of the resource (ex. web_service or postgres)
    """
    STATIC_SITE = "static_site"
    WEB_SERVICE = "web_service"
    PRIVATE_SERVICE = "private_service"
    BACKGROUND_WORKER = "background_worker"
    CRON_JOB = "cron_job"
    REDIS = "redis"
    POSTGRES = "postgres"
    ENVIRONMENT_GROUP = "environment_group"


class GetBlueprintPropertiesStatus(str, Enum):
    CREATED = "created"
    PAUSED = "paused"
    IN_SYNC = "in_sync"
    SYNCING = "syncing"
    ERROR = "error"


class SyncWithCursorSyncPropertiesState(str, Enum):
    CREATED = "created"
    PENDING = "pending"
    RUNNING = "running"
    ERROR = "error"
    SUCCESS = "success"
