# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ServiceLinkType',
]


class ServiceLinkType(str, Enum):
    STATIC = "static"
    WEB = "web"
    PSERV = "pserv"
    WORKER = "worker"
    CRON = "cron"
