# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'Status',
]


class Status(str, Enum):
    PENDING = "pending"
    SUCCESSFUL = "successful"
    UNSUCCESSFUL = "unsuccessful"
    CANCELED = "canceled"
