# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'BackgroundWorkerDetailsCreateEnv',
    'BackgroundWorkerDetailsCreatePlan',
    'BackgroundWorkerDetailsCreatePullRequestPreviewsEnabled',
    'BackgroundWorkerDetailsCreateRegion',
    'BackgroundWorkerDetailsCreateRuntime',
    'BackgroundWorkerDetailsOutputBuildPlan',
    'BackgroundWorkerDetailsOutputEnv',
    'BackgroundWorkerDetailsOutputPlan',
    'BackgroundWorkerDetailsOutputPullRequestPreviewsEnabled',
    'BackgroundWorkerDetailsOutputRegion',
    'CancelJobStatus',
    'ClearCache',
    'CronJobDetailsCreateEnv',
    'CronJobDetailsCreatePlan',
    'CronJobDetailsCreateRegion',
    'CronJobDetailsCreateRuntime',
    'CronJobDetailsOutputBuildPlan',
    'CronJobDetailsOutputEnv',
    'CronJobDetailsOutputPlan',
    'CronJobDetailsOutputRegion',
    'CustomDomainDomainType',
    'CustomDomainVerificationStatus',
    'DeployStatus',
    'DeployTrigger',
    'JobStatus',
    'Paths1services17BserviceId7D1jobscreateresponses200contentapplication1jsonschemaStatus',
    'Plan',
    'PrivateServiceDetailsCreateEnv',
    'PrivateServiceDetailsCreatePlan',
    'PrivateServiceDetailsCreatePullRequestPreviewsEnabled',
    'PrivateServiceDetailsCreateRegion',
    'PrivateServiceDetailsCreateRuntime',
    'PrivateServiceDetailsOutputBuildPlan',
    'PrivateServiceDetailsOutputEnv',
    'PrivateServiceDetailsOutputPlan',
    'PrivateServiceDetailsOutputPullRequestPreviewsEnabled',
    'PrivateServiceDetailsOutputRegion',
    'RegistryCredentialRegistry',
    'RouteCreateType',
    'RouteType',
    'ServerPortProtocol',
    'ServiceAutoDeploy',
    'ServiceCreateAutoDeploy',
    'ServiceNotifyOnFail',
    'ServiceSuspended',
    'ServiceSuspendersItem',
    'StaticSiteDetailsCreatePullRequestPreviewsEnabled',
    'StaticSiteDetailsOutputBuildPlan',
    'StaticSiteDetailsOutputPullRequestPreviewsEnabled',
    'Status',
    'Trigger',
    'Type',
    'WebServiceDetailsCreateEnv',
    'WebServiceDetailsCreatePlan',
    'WebServiceDetailsCreatePullRequestPreviewsEnabled',
    'WebServiceDetailsCreateRegion',
    'WebServiceDetailsCreateRuntime',
    'WebServiceDetailsOutputBuildPlan',
    'WebServiceDetailsOutputEnv',
    'WebServiceDetailsOutputPlan',
    'WebServiceDetailsOutputPullRequestPreviewsEnabled',
    'WebServiceDetailsOutputRegion',
]


class BackgroundWorkerDetailsCreateEnv(str, Enum):
    """
    This field has been deprecated, runtime should be used in its place.
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class BackgroundWorkerDetailsCreatePlan(str, Enum):
    """
    Defaults to "starter"
    """
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"


class BackgroundWorkerDetailsCreatePullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class BackgroundWorkerDetailsCreateRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class BackgroundWorkerDetailsCreateRuntime(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class BackgroundWorkerDetailsOutputBuildPlan(str, Enum):
    STARTER = "starter"
    PERFORMANCE = "performance"


class BackgroundWorkerDetailsOutputEnv(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class BackgroundWorkerDetailsOutputPlan(str, Enum):
    """
    The instance type to use for the preview instance. Note that base services with any paid instance type can't create preview instances with the `free` instance type.
    """
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"
    FREE = "free"
    CUSTOM = "custom"


class BackgroundWorkerDetailsOutputPullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class BackgroundWorkerDetailsOutputRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class CancelJobStatus(str, Enum):
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class ClearCache(str, Enum):
    """
    If `clear`, Render clears the service's build cache before deploying. This can be useful if you're experiencing issues with your build.
    """
    CLEAR = "clear"
    DO_NOT_CLEAR = "do_not_clear"


class CronJobDetailsCreateEnv(str, Enum):
    """
    This field has been deprecated, runtime should be used in its place.
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class CronJobDetailsCreatePlan(str, Enum):
    """
    Defaults to "starter"
    """
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"


class CronJobDetailsCreateRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class CronJobDetailsCreateRuntime(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class CronJobDetailsOutputBuildPlan(str, Enum):
    STARTER = "starter"
    PERFORMANCE = "performance"


class CronJobDetailsOutputEnv(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class CronJobDetailsOutputPlan(str, Enum):
    """
    The instance type to use for the preview instance. Note that base services with any paid instance type can't create preview instances with the `free` instance type.
    """
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"
    FREE = "free"
    CUSTOM = "custom"


class CronJobDetailsOutputRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class CustomDomainDomainType(str, Enum):
    APEX = "apex"
    SUBDOMAIN = "subdomain"


class CustomDomainVerificationStatus(str, Enum):
    VERIFIED = "verified"
    UNVERIFIED = "unverified"


class DeployStatus(str, Enum):
    CREATED = "created"
    BUILD_IN_PROGRESS = "build_in_progress"
    UPDATE_IN_PROGRESS = "update_in_progress"
    LIVE = "live"
    DEACTIVATED = "deactivated"
    BUILD_FAILED = "build_failed"
    UPDATE_FAILED = "update_failed"
    CANCELED = "canceled"
    PRE_DEPLOY_IN_PROGRESS = "pre_deploy_in_progress"
    PRE_DEPLOY_FAILED = "pre_deploy_failed"


class DeployTrigger(str, Enum):
    API = "api"
    BLUEPRINT_SYNC = "blueprint_sync"
    DEPLOY_HOOK = "deploy_hook"
    DEPLOYED_BY_RENDER = "deployed_by_render"
    MANUAL = "manual"
    OTHER = "other"
    NEW_COMMIT = "new_commit"
    ROLLBACK = "rollback"
    SERVICE_RESUMED = "service_resumed"
    SERVICE_UPDATED = "service_updated"


class JobStatus(str, Enum):
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class Paths1services17BserviceId7D1jobscreateresponses200contentapplication1jsonschemaStatus(str, Enum):
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class Plan(str, Enum):
    """
    The instance type to use for the preview instance. Note that base services with any paid instance type can't create preview instances with the `free` instance type.
    """
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"
    FREE = "free"
    CUSTOM = "custom"


class PrivateServiceDetailsCreateEnv(str, Enum):
    """
    This field has been deprecated, runtime should be used in its place.
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class PrivateServiceDetailsCreatePlan(str, Enum):
    """
    Defaults to "starter"
    """
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"


class PrivateServiceDetailsCreatePullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class PrivateServiceDetailsCreateRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class PrivateServiceDetailsCreateRuntime(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class PrivateServiceDetailsOutputBuildPlan(str, Enum):
    STARTER = "starter"
    PERFORMANCE = "performance"


class PrivateServiceDetailsOutputEnv(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class PrivateServiceDetailsOutputPlan(str, Enum):
    """
    The instance type to use for the preview instance. Note that base services with any paid instance type can't create preview instances with the `free` instance type.
    """
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"
    FREE = "free"
    CUSTOM = "custom"


class PrivateServiceDetailsOutputPullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class PrivateServiceDetailsOutputRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class RegistryCredentialRegistry(str, Enum):
    """
    The registry to use this credential with
    """
    GITHUB = "GITHUB"
    GITLAB = "GITLAB"
    DOCKER = "DOCKER"
    GOOGLE_ARTIFACT = "GOOGLE_ARTIFACT"


class RouteCreateType(str, Enum):
    REDIRECT = "redirect"
    REWRITE = "rewrite"


class RouteType(str, Enum):
    REDIRECT = "redirect"
    REWRITE = "rewrite"


class ServerPortProtocol(str, Enum):
    TCP = "TCP"
    UDP = "UDP"


class ServiceAutoDeploy(str, Enum):
    YES = "yes"
    NO = "no"


class ServiceCreateAutoDeploy(str, Enum):
    YES = "yes"
    NO = "no"


class ServiceNotifyOnFail(str, Enum):
    DEFAULT = "default"
    NOTIFY = "notify"
    IGNORE = "ignore"


class ServiceSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class ServiceSuspendersItem(str, Enum):
    ADMIN = "admin"
    BILLING = "billing"
    USER = "user"
    PARENT_SERVICE = "parent_service"
    UNKNOWN = "unknown"


class StaticSiteDetailsCreatePullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class StaticSiteDetailsOutputBuildPlan(str, Enum):
    STARTER = "starter"
    PERFORMANCE = "performance"


class StaticSiteDetailsOutputPullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class Status(str, Enum):
    CREATED = "created"
    BUILD_IN_PROGRESS = "build_in_progress"
    UPDATE_IN_PROGRESS = "update_in_progress"
    LIVE = "live"
    DEACTIVATED = "deactivated"
    BUILD_FAILED = "build_failed"
    UPDATE_FAILED = "update_failed"
    CANCELED = "canceled"
    PRE_DEPLOY_IN_PROGRESS = "pre_deploy_in_progress"
    PRE_DEPLOY_FAILED = "pre_deploy_failed"


class Trigger(str, Enum):
    API = "api"
    BLUEPRINT_SYNC = "blueprint_sync"
    DEPLOY_HOOK = "deploy_hook"
    DEPLOYED_BY_RENDER = "deployed_by_render"
    MANUAL = "manual"
    OTHER = "other"
    NEW_COMMIT = "new_commit"
    ROLLBACK = "rollback"
    SERVICE_RESUMED = "service_resumed"
    SERVICE_UPDATED = "service_updated"


class Type(str, Enum):
    REDIRECT = "redirect"
    REWRITE = "rewrite"


class WebServiceDetailsCreateEnv(str, Enum):
    """
    This field has been deprecated, runtime should be used in its place.
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class WebServiceDetailsCreatePlan(str, Enum):
    """
    Defaults to "starter"
    """
    STARTER = "starter"
    STANDARD = "standard"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"


class WebServiceDetailsCreatePullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class WebServiceDetailsCreateRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"


class WebServiceDetailsCreateRuntime(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class WebServiceDetailsOutputBuildPlan(str, Enum):
    STARTER = "starter"
    PERFORMANCE = "performance"


class WebServiceDetailsOutputEnv(str, Enum):
    """
    Runtime
    """
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"
    IMAGE = "image"


class WebServiceDetailsOutputPlan(str, Enum):
    """
    The instance type to use for the preview instance. Note that base services with any paid instance type can't create preview instances with the `free` instance type.
    """
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"
    FREE = "free"
    CUSTOM = "custom"


class WebServiceDetailsOutputPullRequestPreviewsEnabled(str, Enum):
    """
    Defaults to "no"
    """
    YES = "yes"
    NO = "no"


class WebServiceDetailsOutputRegion(str, Enum):
    """
    Defaults to "oregon"
    """
    FRANKFURT = "frankfurt"
    OREGON = "oregon"
    OHIO = "ohio"
    SINGAPORE = "singapore"
    VIRGINIA = "virginia"
