# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'BlueprintWithCursor',
    'BlueprintWithCursorBlueprintProperties',
    'GetBlueprintPropertiesResourcesItemProperties',
    'SyncWithCursor',
    'SyncWithCursorSyncProperties',
    'SyncWithCursorSyncPropertiesCommitProperties',
]

@pulumi.output_type
class BlueprintWithCursor(dict):
    """
    A blueprint with a cursor
    """
    def __init__(__self__, *,
                 blueprint: 'outputs.BlueprintWithCursorBlueprintProperties',
                 cursor: str):
        """
        A blueprint with a cursor
        """
        pulumi.set(__self__, "blueprint", blueprint)
        pulumi.set(__self__, "cursor", cursor)

    @property
    @pulumi.getter
    def blueprint(self) -> 'outputs.BlueprintWithCursorBlueprintProperties':
        return pulumi.get(self, "blueprint")

    @property
    @pulumi.getter
    def cursor(self) -> str:
        return pulumi.get(self, "cursor")


@pulumi.output_type
class BlueprintWithCursorBlueprintProperties(dict):
    def __init__(__self__, *,
                 auto_sync: bool,
                 branch: str,
                 id: str,
                 name: str,
                 repo: str,
                 status: 'BlueprintWithCursorBlueprintPropertiesStatus',
                 last_sync: Optional[str] = None):
        """
        :param bool auto_sync: Automatically sync changes to render.yaml
        """
        pulumi.set(__self__, "auto_sync", auto_sync)
        pulumi.set(__self__, "branch", branch)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "repo", repo)
        pulumi.set(__self__, "status", status)
        if last_sync is not None:
            pulumi.set(__self__, "last_sync", last_sync)

    @property
    @pulumi.getter(name="autoSync")
    def auto_sync(self) -> bool:
        """
        Automatically sync changes to render.yaml
        """
        return pulumi.get(self, "auto_sync")

    @property
    @pulumi.getter
    def branch(self) -> str:
        return pulumi.get(self, "branch")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def repo(self) -> str:
        return pulumi.get(self, "repo")

    @property
    @pulumi.getter
    def status(self) -> 'BlueprintWithCursorBlueprintPropertiesStatus':
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="lastSync")
    def last_sync(self) -> Optional[str]:
        return pulumi.get(self, "last_sync")


@pulumi.output_type
class GetBlueprintPropertiesResourcesItemProperties(dict):
    def __init__(__self__, *,
                 id: str,
                 name: str,
                 type: 'GetBlueprintPropertiesResourcesItemPropertiesType'):
        """
        :param 'GetBlueprintPropertiesResourcesItemPropertiesType' type: type of the resource (ex. web_service or postgres)
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> 'GetBlueprintPropertiesResourcesItemPropertiesType':
        """
        type of the resource (ex. web_service or postgres)
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class SyncWithCursor(dict):
    """
    A blueprint sync with a cursor
    """
    def __init__(__self__, *,
                 cursor: str,
                 sync: 'outputs.SyncWithCursorSyncProperties'):
        """
        A blueprint sync with a cursor
        """
        pulumi.set(__self__, "cursor", cursor)
        pulumi.set(__self__, "sync", sync)

    @property
    @pulumi.getter
    def cursor(self) -> str:
        return pulumi.get(self, "cursor")

    @property
    @pulumi.getter
    def sync(self) -> 'outputs.SyncWithCursorSyncProperties':
        return pulumi.get(self, "sync")


@pulumi.output_type
class SyncWithCursorSyncProperties(dict):
    def __init__(__self__, *,
                 commit: 'outputs.SyncWithCursorSyncPropertiesCommitProperties',
                 id: str,
                 state: 'SyncWithCursorSyncPropertiesState',
                 completed_at: Optional[str] = None,
                 started_at: Optional[str] = None):
        pulumi.set(__self__, "commit", commit)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "state", state)
        if completed_at is not None:
            pulumi.set(__self__, "completed_at", completed_at)
        if started_at is not None:
            pulumi.set(__self__, "started_at", started_at)

    @property
    @pulumi.getter
    def commit(self) -> 'outputs.SyncWithCursorSyncPropertiesCommitProperties':
        return pulumi.get(self, "commit")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> 'SyncWithCursorSyncPropertiesState':
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> Optional[str]:
        return pulumi.get(self, "completed_at")

    @property
    @pulumi.getter(name="startedAt")
    def started_at(self) -> Optional[str]:
        return pulumi.get(self, "started_at")


@pulumi.output_type
class SyncWithCursorSyncPropertiesCommitProperties(dict):
    def __init__(__self__, *,
                 id: str):
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")


